@@ -355,7 +355,7 @@ def selectplots(plotsDF):
         startRange=(i-i%10  if 0<i%10<6 else  i-i%5) if i%10 else i-5
         return [ startRange+i for i in range(1,6) ]
 
-    rtplot=tplot+abs(tplot%5-5)
+    rtplot = (tplot+abs(tplot%5-5)) if tplot%5 else tplot
     splotinterval=int(rtplot/4)
     stmflag=True; grpflag=True
     print('\n\n')
